package net.wanji.utc.controller;

import net.wanji.utc.common.Result;
import net.wanji.utc.common.exception.ControlException;
import net.wanji.utc.common.typeenum.BasicEnum;
import net.wanji.utc.mapper.CrossInfoMapper;
import net.wanji.utc.po.CrossInfoPO;
import net.wanji.utc.service.ControlCommandService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.RestController;

import static net.wanji.utc.common.ResultEnum.BODY_NOT_MATCH;

/**
 * 控制指令接口
 *
 * @author wuxiaokai
 * @date 2022/11/15 13:21:10
 */
@RestController
@RequestMapping("/controlCommand")
public class ControlCommandController {

    @Value("${signal.mock}")
    private boolean mock;

    @Autowired
    private CrossInfoMapper crossInfoMapper;

    @Autowired
    private ControlCommandService hkControlCommandService;

    @PostMapping("/allRedControl")
    public <T> Result<T> allRedControl(@RequestParam String signalId, @RequestParam Integer command) {
        if (mock) return Result.success();
        CrossInfoPO crossInfoPO = crossInfoMapper.selectByCode(signalId);
        if (crossInfoPO == null) {
            throw new ControlException(BODY_NOT_MATCH.getResultCode(), "参数错误，信号机ID不正确。");
        }
        Integer manufacturerId = crossInfoPO.getManufacturerId();
        Result<T> result = new Result<>();
        if (manufacturerId.equals(BasicEnum.ManufacturerEnum.HK.getCode())) {
            result = hkControlCommandService.allRedControl(signalId, null, null, command);
        } else {
            // todo else
        }
        return result;
    }
}
